<?php
/**
 * Blog Theme functions and definitions
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1170;
}

/**
 * Landyland Setup
 */

if ( ! function_exists( 'landyland_setup' ) ) :
function landyland_setup() {

	//	Make theme available for translation.
	load_theme_textdomain( 'landyland', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	//	Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	//	Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 510, true );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'landyland' ),
		'topmenu' => esc_html__( 'Top Menu', 'landyland' ),
	) );

	//	Switch default core markup for search form, comment form, and comments
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
	
	//This theme support custom header
    add_theme_support( 'custom-header' );

    //This theme support custom backgrounds
    add_theme_support( 'custom-backgrounds' );
	
	//	Enable support for Post Formats.
	add_theme_support( 'post-formats', array('image', 'gallery', 'link', 'quote', 'video', 'aside', 'status'));

}
endif;
add_action( 'after_setup_theme', 'landyland_setup' );


/**
 * Include files
 */

//	Theme Functions
require_once ( get_template_directory() .'/framework/theme_functions.php' );
 
//	Theme style, jQuery
require_once ( get_template_directory() .'/framework/enqueue.php' );

//	Plugin Recommendations
require_once ( get_template_directory() .'/framework/plugins/install-plugin.php' );

//	Breadcrumbs
require_once( get_template_directory() .'/framework/breadcrumbs.php' );

//	Aqua Resizer
require_once( get_template_directory() .'/framework/aq_resizer.php' );

//	Widgets
require_once ( get_template_directory() .'/framework/widgets/widgets.php' );

//	Megamenu Framework
require_once( get_template_directory() .'/framework/megamenu.php' );

//	Redux Theme Options
if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
	require_once( get_template_directory() . '/framework/theme-options/options.php' );
}